@@ -12,8 +12,8 @@ class InteligerQuerySet(models.QuerySet):
         return self.filter(status=True)
 
     def desabilitar(self, request_=None):
-        usuario = request_.user if request_ is not None else None
-        qs = self.update(status=False, usr_delete=usuario, dat_delete=timezone.now())
+        usuario = request_.user.id if request_ is not None else None
+        qs = self.update(status=False, usr_delete_id=usuario, dat_delete=timezone.now())
         return qs
 
 
@@ -49,9 +49,9 @@ class DatLog(models.Model):
 
 
 class UsrLog(models.Model):
-    usr_insercao = models.ForeignKey('usr.Profile', on_delete=models.SET_NULL, null=True, related_name='%(app_label)s_%(class)s_usr_insercao')
-    usr_edicao = models.ForeignKey('usr.Profile', on_delete=models.SET_NULL, null=True, related_name='%(app_label)s_%(class)s_usr_edicao')
-    usr_delete = models.ForeignKey('usr.Profile', on_delete=models.SET_NULL, null=True, related_name='%(app_label)s_%(class)s_usr_delete')
+    usr_insercao = models.ForeignKey('usr.Profile', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr_insercao')
+    usr_edicao = models.ForeignKey('usr.Profile', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr_edicao')
+    usr_delete = models.ForeignKey('usr.Profile', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr_delete')
 
     class Meta:
         abstract = True
@@ -69,17 +69,17 @@ class Log(DatLog, UsrLog):
     def save(self, request_=None, *args, **kwargs):
         if request_ is not None:
             if self.pk is None:
-                self.usr_insercao = request_.user if request_ is not None else None
+                self.usr_insercao_id = request_.user.id if request_ is not None else None
                 self.dat_insercao = timezone.now()
                 self.status = True
             else:
-                self.usr_edicao = request_.user if request_ is not None else None
+                self.usr_edicao_id = request_.user.id if request_ is not None else None
                 self.dat_edicao = timezone.now()
         super(Log, self).save(*args, **kwargs)
 
     def desabilitar(self, request_=None, *args, **kwargs):
         self.status = False
-        self.usr_delete = request_.user if request_ is not None else None
+        self.usr_delete_id = request_.user.id if request_ is not None else None
         self.dat_delete = timezone.now()
         super(Log, self).save(*args, **kwargs)
 
@@ -91,6 +91,64 @@ class Tipo(Log):
     descricao = models.TextField(null=True)
 
     class Meta:
-        #db_table = u'"core\".\"tipo"'
         db_table = 'tipo'
         unique_together = ('codigo', 'tipo')
+        managed = False
+
+
+class Empresa(Log):
+    nome = models.CharField(max_length=100, null=True)
+
+    class Meta:
+        db_table = 'empresa'
+        managed = False
+
+
+class EmpresaLog(models.Model):
+    empresa = models.ForeignKey(Empresa, on_delete=models.DO_NOTHING, null=True)
+
+    class Meta:
+        abstract = True
+
+
+class Sistema(Log):
+    nome = models.CharField(max_length=100, primary_key=True)
+    nm_descritivo = models.CharField(max_length=200, null=True)
+
+    class Meta:
+        db_table = 'sistema'
+        managed = False
+
+
+class Versao(Log):
+    sistema = models.ForeignKey(Sistema, null=True, on_delete=models.DO_NOTHING)
+    responsavel = models.ForeignKey('usr.Profile', null=True, on_delete=models.DO_NOTHING)
+    dat_atualizacao = models.DateField(null=True)
+    codigo = models.CharField(max_length=100, null=True)
+    commit = models.CharField(max_length=50, null=True)
+    descricao = models.TextField(null=True)
+
+    class Meta:
+        db_table = 'versao'
+        managed = False
+
+
+class VersaoItem(Log):
+    versao = models.ForeignKey(Versao, null=True, on_delete=models.DO_NOTHING)
+    responsavel = models.ForeignKey('usr.Profile', null=True, on_delete=models.DO_NOTHING)
+    ordem = models.IntegerField(null=True)
+    descricao = models.TextField(null=True)
+
+    class Meta:
+        db_table = 'versaoitem'
+        managed = False
+
+
+class Erro(Log):
+    nome = models.CharField(max_length=100)
+    codigo = models.CharField(max_length=200, null=True)
+    descricao = models.TextField(null=True)
+
+    class Meta:
+        db_table = 'erro'
+        managed = False
\ No newline at end of file
